public inbox for libstdc++@gcc.gnu.org
 help / color / mirror / Atom feed
* [committed] libstdc++: Fix compare_exchange_padding.cc test for std::atomic_ref
@ 2022-09-16 20:21 Jonathan Wakely
  2022-10-31 15:34 ` Eric Botcazou
  0 siblings, 1 reply; 9+ messages in thread
From: Jonathan Wakely @ 2022-09-16 20:21 UTC (permalink / raw)
  To: libstdc++, gcc-patches

Tested x86_64-linux, pushed to trunk.

The test was only failing for me with -m32 (and not -m64), so I didn't
notice until now. That probably means we should make the test fail more
reliably if the padding isn't being cleared.

-- >8 --

This test was written assuming that std::atomic_ref clears its target's
padding on construction, but that could introduce data races. Change the
test to store a value after construction and check that its padding is
cleared by the store.

libstdc++-v3/ChangeLog:

	* testsuite/29_atomics/atomic_ref/compare_exchange_padding.cc:
	Store value with non-zero padding bits after construction.
---
 .../29_atomics/atomic_ref/compare_exchange_padding.cc | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/libstdc++-v3/testsuite/29_atomics/atomic_ref/compare_exchange_padding.cc b/libstdc++-v3/testsuite/29_atomics/atomic_ref/compare_exchange_padding.cc
index 1b1a12dddda..e9f8a4bdf2a 100644
--- a/libstdc++-v3/testsuite/29_atomics/atomic_ref/compare_exchange_padding.cc
+++ b/libstdc++-v3/testsuite/29_atomics/atomic_ref/compare_exchange_padding.cc
@@ -20,14 +20,15 @@ int
 main ()
 {
   S s;
-  fill_struct(s);
-  s.c = 'a';
-  s.s = 42;
-
   S ss{ s };
+  fill_struct(ss);
+  ss.c = 'a';
+  ss.s = 42;
+
   std::atomic_ref<S> as{ s };
+  as.store(ss);
   auto ts = as.load();
-  VERIFY( !compare_struct(ss, ts) ); // padding cleared on construction
+  VERIFY( !compare_struct(ss, ts) ); // padding cleared on store
   as.exchange(ss);
   auto es = as.load();
   VERIFY( compare_struct(ts, es) ); // padding cleared on exchange
-- 
2.37.3


^ permalink raw reply	[flat|nested] 9+ messages in thread

end of thread, other threads:[~2023-09-02  8:03 UTC | newest]

Thread overview: 9+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-09-16 20:21 [committed] libstdc++: Fix compare_exchange_padding.cc test for std::atomic_ref Jonathan Wakely
2022-10-31 15:34 ` Eric Botcazou
2022-10-31 15:37   ` Jonathan Wakely
2022-10-31 17:03     ` Eric Botcazou
2022-10-31 17:05       ` Jonathan Wakely
2022-11-01 13:53         ` Jonathan Wakely
2022-11-01 15:26           ` Eric Botcazou
2023-09-01 15:21   ` Jonathan Wakely
2023-09-01 18:14     ` Eric Botcazou

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).